@@ -24,8 +24,6 @@ import org.eclipse.e4.ui.progress.internal.legacy.Policy;
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.dialogs.ProgressMonitorDialog;
 import org.eclipse.jface.operation.IRunnableWithProgress;
-import org.eclipse.jface.viewers.Viewer;
-import org.eclipse.jface.viewers.ViewerComparator;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
@@ -58,6 +56,7 @@ public class ProgressMonitorJobsDialog extends ProgressMonitorDialog {
 
 	private long watchTime = -1;
 
+	/** Flag to prevent nested closes. */
 	protected boolean alreadyClosed = false;
 
 	private IProgressMonitor wrapperedMonitor;
@@ -70,14 +69,21 @@ public class ProgressMonitorJobsDialog extends ProgressMonitorDialog {
 
 	private FinishedJobs finishedJobs;
 
-	//Cache initial enablement in case the enablement state is set
-	//before the button is created
+	/**
+	 * Cache initial enablement in case the enablement state is set before the
+	 * button is created
+	 */
 	protected boolean enableDetailsButton = false;
 
 	/**
 	 * Create a new instance of the receiver.
 	 *
-	 * @param parent
+	 * @param parent                 dialogs parent shell
+	 * @param progressService        service to do progress related work
+	 * @param progressManager        helper to manage progress
+	 * @param finishedJobs           the singleton to store finished jobs which
+	 *                               should kept
+	 * @param contentProviderFactory the content provider factory
 	 */
 	public ProgressMonitorJobsDialog(Shell parent,
 			IProgressService progressService, ProgressManager progressManager,
@@ -98,7 +104,8 @@ public class ProgressMonitorJobsDialog extends ProgressMonitorDialog {
 
 	/**
 	 * Create the extensions to the dialog area.
-	 * @param parent
+	 *
+	 * @param parent the parent composite
 	 */
 	protected void createExtendedDialogArea(Composite parent) {
 		viewerComposite = new Composite(parent, SWT.NONE);
@@ -115,7 +122,6 @@ public class ProgressMonitorJobsDialog extends ProgressMonitorDialog {
 	/**
 	 * The details button has been selected. Open or close the progress viewer
 	 * as appropriate.
-	 *
 	 */
 	void handleDetailsButtonSelect() {
 		Shell shell = getShell();
@@ -136,13 +142,7 @@ public class ProgressMonitorJobsDialog extends ProgressMonitorDialog {
 
 			viewer = new DetailedProgressViewer(viewerComposite, SWT.MULTI
 					| SWT.H_SCROLL | SWT.V_SCROLL | SWT.BORDER, progressService, finishedJobs);
-			viewer.setComparator(new ViewerComparator() {
-				@Override
-				@SuppressWarnings("unchecked")
-				public int compare(Viewer testViewer, Object e1, Object e2) {
-					return ((Comparable<Object>) e1).compareTo(e2);
-				}
-			});
+			viewer.setComparator(ProgressManagerUtil.getProgressViewerComparator());
 
 			viewer.setContentProvider(contentProviderFactory
 					.getProgressViewerContentProvider(viewer, true, false));
