@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2018 BestSolution.at and others.
+ * Copyright (c) 2010, 2020 BestSolution.at and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,6 +14,7 @@
  *     René Brandstetter - Bug 419749
  *     Brian de Alwis (MTI) - Bug 433053
  *     Alexandra Buzila - Refactoring, Bug 475934
+ *     Gerhard Kreuzer - Bug 561324
  ******************************************************************************/
 
 package org.eclipse.e4.ui.internal.workbench;
@@ -202,9 +203,7 @@ public class ModelAssembler {
 
 	private void addAllBucketFragmentWrapper(Bucket bucket, List<ModelFragmentWrapper> fragmentList,
 			Set<String> checkedElementIds) {
-		for (ModelFragmentWrapper wrapper : bucket.wrapper) {
-			fragmentList.add(wrapper);
-		}
+		fragmentList.addAll(bucket.wrapper);
 		checkedElementIds.addAll(bucket.containedElementIds);
 		for (Bucket child : bucket.dependencies) {
 			addAllBucketFragmentWrapper(child, fragmentList, checkedElementIds);
@@ -250,7 +249,7 @@ public class ModelAssembler {
 		if (severity == Diagnostic.ERROR) {
 			logger.error(
 					"Fragment from \"{0}\" of \"{1}\" could not be validated and was not merged: " //$NON-NLS-1$
-							+ fragment.toString(), contributorURI, contributorName);
+							+ fragment, contributorURI, contributorName);
 		}
 
 		List<MApplicationElement> merged = processModelFragment(fragment, contributorURI, checkExist);
@@ -295,7 +294,7 @@ public class ModelAssembler {
 		try {
 			resource = resourceSet.getResource(uri, true);
 		} catch (RuntimeException e) {
-			logger.warn(e, "Unable to read model extension from \"" + uri.toString() + "\" of \"" + bundleName + "\""); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+			logger.warn(e, "Unable to read model extension from \"" + uri + "\" of \"" + bundleName + "\""); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 			return null;
 		}
 
@@ -445,9 +444,6 @@ public class ModelAssembler {
 		Map<MApplicationElement, MApplicationElement> importMaps = new HashMap<>();
 		for (MApplicationElement importedElement : imports) {
 			MApplicationElement realElement = ModelUtils.findElementById(application, importedElement.getElementId());
-			if (realElement == null) {
-				logger.warn("Could not resolve an import element for '" + importedElement.getElementId() + "'"); //$NON-NLS-1$ //$NON-NLS-2$
-			}
 			importMaps.put(importedElement, realElement);
 		}
 
@@ -467,10 +463,11 @@ public class ModelAssembler {
 					MApplicationElement el = null;
 					if (importObject instanceof MApplicationElement) {
 						el = importMaps.get((MApplicationElement) importObject);
-					}
 
-					if (el == null) {
-						logger.warn("Could not resolve import for " + el); //$NON-NLS-1$
+						if (el == null) {
+							logger.warn("Could not resolve import for " //$NON-NLS-1$
+									+ ((MApplicationElement) importObject).getElementId());
+						}
 					}
 
 					final EObject interalTarget = o;
