@@ -498,7 +498,7 @@ public abstract class WizardExportPage extends WizardDataTransferPage {
 				IDEWorkbenchMessages.WizardExportPage_selectResourcesToExport);
 		if (containerPath != null) { // null means user cancelled
 			String relativePath = containerPath.makeRelative().toString();
-			if (!relativePath.toString().equals(resourceNameField.getText())) {
+			if (!relativePath.equals(resourceNameField.getText())) {
 				resetSelectedResources();
 				resourceNameField.setText(relativePath);
 			}
@@ -817,7 +817,7 @@ public abstract class WizardExportPage extends WizardDataTransferPage {
 	/**
 	 * Set the resource whos name we will display.
 	 *
-	 * @param resource
+	 * @param resource the resource to display
 	 */
 	protected void setResourceToDisplay(IResource resource) {
 		setResourceFieldValue(resource.getFullPath().makeRelative().toString());
