@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -18,6 +18,8 @@
  *  Lars Vogel <Lars.Vogel@gmail.com> - Bug 440810
  *  Patrik Suzzi <psuzzi@gmail.com> - Bug 485133
  *  Lucas Bullen <lbullen@redhat.com> - Bug 525974, 531332
+ *  Emmanuel Chebbi <emmanuel.chebbi@outlook.fr> - Bug 214491
+ *     - [Dialogs] FilteredItemsSelectionDialog should respect setInitialSelections()
  *******************************************************************************/
 package org.eclipse.ui.dialogs;
 
@@ -56,7 +58,7 @@ import org.eclipse.jface.action.IMenuManager;
 import org.eclipse.jface.action.LegacyActionTools;
 import org.eclipse.jface.action.MenuManager;
 import org.eclipse.jface.dialogs.IDialogSettings;
-import org.eclipse.jface.text.contentassist.BoldStylerProvider;
+import org.eclipse.jface.viewers.BoldStylerProvider;
 import org.eclipse.jface.viewers.ContentViewer;
 import org.eclipse.jface.viewers.DelegatingStyledCellLabelProvider.IStyledLabelProvider;
 import org.eclipse.jface.viewers.IColorProvider;
@@ -162,7 +164,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 
 	private Text pattern;
 
-	private TableViewer list;
+	private TableViewer tableViewer;
 
 	private DetailsContentViewer details;
 
@@ -229,6 +231,11 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 
 	private IStyledStringHighlighter styledStringHighlighter;
 
+	/**
+	 * Used to set initial selection in {@link #refresh()}.
+	 */
+	private boolean isShownForTheFirstTime = true;
+
 	/**
 	 * Creates a new instance of the class.
 	 *
@@ -470,7 +477,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 		listLabel.addTraverseListener(e -> {
 			if (e.detail == SWT.TRAVERSE_MNEMONIC && e.doit) {
 				e.detail = SWT.TRAVERSE_NONE;
-				list.getTable().setFocus();
+				tableViewer.getTable().setFocus();
 			}
 		});
 
@@ -548,7 +555,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 	 * @since 3.5
 	 */
 	protected void fillContextMenu(IMenuManager menuManager) {
-		List<?> selectedElements = list.getStructuredSelection().toList();
+		List<?> selectedElements = tableViewer.getStructuredSelection().toList();
 
 		Object item = null;
 
@@ -576,7 +583,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 		contextMenuManager.setRemoveAllWhenShown(true);
 		contextMenuManager.addMenuListener(manager -> fillContextMenu(manager));
 
-		final Table table = list.getTable();
+		final Table table = tableViewer.getTable();
 		Menu menu = contextMenuManager.createContextMenu(table);
 		table.setMenu(menu);
 	}
@@ -617,8 +624,8 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 
 		final Label listLabel = createLabels(content);
 
-		list = new TableViewer(content, (multi ? SWT.MULTI : SWT.SINGLE) | SWT.BORDER | SWT.V_SCROLL | SWT.VIRTUAL);
-		list.getTable().getAccessible().addAccessibleListener(new AccessibleAdapter() {
+		tableViewer = new TableViewer(content, (multi ? SWT.MULTI : SWT.SINGLE) | SWT.BORDER | SWT.V_SCROLL | SWT.VIRTUAL);
+		tableViewer.getTable().getAccessible().addAccessibleListener(new AccessibleAdapter() {
 			@Override
 			public void getName(AccessibleEvent e) {
 				if (e.childID == ACC.CHILDID_SELF) {
@@ -626,14 +633,14 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 				}
 			}
 		});
-		list.setContentProvider(contentProvider);
-		list.setLabelProvider(getItemsListLabelProvider());
-		list.setInput(new Object[0]);
-		list.setItemCount(contentProvider.getNumberOfElements());
+		tableViewer.setContentProvider(contentProvider);
+		tableViewer.setLabelProvider(getItemsListLabelProvider());
+		tableViewer.setInput(new Object[0]);
+		tableViewer.setItemCount(contentProvider.getNumberOfElements());
 		gd = new GridData(GridData.FILL_BOTH);
-		applyDialogFont(list.getTable());
-		gd.heightHint = list.getTable().getItemHeight() * 15;
-		list.getTable().setLayoutData(gd);
+		applyDialogFont(tableViewer.getTable());
+		gd.heightHint = tableViewer.getTable().getItemHeight() * 15;
+		tableViewer.getTable().setLayoutData(gd);
 
 		createPopupMenu();
 
@@ -643,27 +650,27 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 			@Override
 			public void keyPressed(KeyEvent e) {
 				if (e.keyCode == SWT.ARROW_DOWN) {
-					if (list.getTable().getItemCount() > 0) {
-						list.getTable().setFocus();
+					if (tableViewer.getTable().getItemCount() > 0) {
+						tableViewer.getTable().setFocus();
 					}
 				}
 			}
 		});
 
-		list.addSelectionChangedListener(event -> {
+		tableViewer.addSelectionChangedListener(event -> {
 			StructuredSelection selection = (StructuredSelection) event.getSelection();
 			handleSelected(selection);
 		});
 
-		list.addDoubleClickListener(event -> handleDoubleClick());
+		tableViewer.addDoubleClickListener(event -> handleDoubleClick());
 
-		list.getTable().addKeyListener(new KeyAdapter() {
+		tableViewer.getTable().addKeyListener(new KeyAdapter() {
 			@Override
 			public void keyPressed(KeyEvent e) {
 
 				if (e.keyCode == SWT.DEL) {
 
-					List<?> selectedElements = ((StructuredSelection) list.getSelection()).toList();
+					List<?> selectedElements = ((StructuredSelection) tableViewer.getSelection()).toList();
 
 					Object item = null;
 					boolean isSelectedHistory = true;
@@ -681,25 +688,25 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 				}
 
 				if (e.keyCode == SWT.ARROW_UP && (e.stateMask & SWT.SHIFT) != 0 && (e.stateMask & SWT.CTRL) != 0) {
-					IStructuredSelection selection = list.getStructuredSelection();
+					IStructuredSelection selection = tableViewer.getStructuredSelection();
 
 					if (selection.size() == 1) {
 						Object element = selection.getFirstElement();
-						if (element.equals(list.getElementAt(0))) {
+						if (element.equals(tableViewer.getElementAt(0))) {
 							pattern.setFocus();
 						}
-						if (list.getElementAt(list.getTable().getSelectionIndex() - 1) instanceof ItemsListSeparator)
-							list.getTable().setSelection(list.getTable().getSelectionIndex() - 1);
-						list.getTable().notifyListeners(SWT.Selection, new Event());
+						if (tableViewer.getElementAt(tableViewer.getTable().getSelectionIndex() - 1) instanceof ItemsListSeparator)
+							tableViewer.getTable().setSelection(tableViewer.getTable().getSelectionIndex() - 1);
+						tableViewer.getTable().notifyListeners(SWT.Selection, new Event());
 
 					}
 				}
 
 				if (e.keyCode == SWT.ARROW_DOWN && (e.stateMask & SWT.SHIFT) != 0 && (e.stateMask & SWT.CTRL) != 0) {
 
-					if (list.getElementAt(list.getTable().getSelectionIndex() + 1) instanceof ItemsListSeparator)
-						list.getTable().setSelection(list.getTable().getSelectionIndex() + 1);
-					list.getTable().notifyListeners(SWT.Selection, new Event());
+					if (tableViewer.getElementAt(tableViewer.getTable().getSelectionIndex() + 1) instanceof ItemsListSeparator)
+						tableViewer.getTable().setSelection(tableViewer.getTable().getSelectionIndex() + 1);
+					tableViewer.getTable().notifyListeners(SWT.Selection, new Event());
 				}
 
 			}
@@ -788,7 +795,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 			status = new Status(IStatus.ERROR, PlatformUI.PLUGIN_ID, IStatus.ERROR, EMPTY_STRING, null);
 
 			if (lastSelection != null && getListSelectionLabelDecorator() != null) {
-				list.update(lastSelection, null);
+				tableViewer.update(lastSelection, null);
 			}
 
 			currentSelection = null;
@@ -801,9 +808,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 			Object item = null;
 			IStatus tempStatus = null;
 
-			for (Iterator<?> it = items.iterator(); it.hasNext();) {
-				Object o = it.next();
-
+			for (Object o : items) {
 				if (o instanceof ItemsListSeparator) {
 					continue;
 				}
@@ -822,11 +827,11 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 			}
 
 			if (lastSelection != null && getListSelectionLabelDecorator() != null) {
-				list.update(lastSelection, null);
+				tableViewer.update(lastSelection, null);
 			}
 
 			if (getListSelectionLabelDecorator() != null) {
-				list.update(currentSelection, null);
+				tableViewer.update(currentSelection, null);
 			}
 		}
 
@@ -857,25 +862,29 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 	 * Refreshes the dialog - has to be called in UI thread.
 	 */
 	public void refresh() {
-		if (list != null && !list.getTable().isDisposed()) {
+		if (tableViewer != null && !tableViewer.getTable().isDisposed()) {
 
-			List<?> lastRefreshSelection = ((StructuredSelection) list.getSelection()).toList();
-			list.getTable().deselectAll();
+			List<Object> lastRefreshSelection = ((StructuredSelection) tableViewer.getSelection()).toList();
+			tableViewer.getTable().deselectAll();
 
-			list.setItemCount(contentProvider.getNumberOfElements());
-			list.refresh();
+			tableViewer.setItemCount(contentProvider.getNumberOfElements());
+			tableViewer.refresh();
 
-			if (list.getTable().getItemCount() > 0) {
+			if (tableViewer.getTable().getItemCount() > 0) {
+				if (isShownForTheFirstTime) {
+					isShownForTheFirstTime = false;
+					lastRefreshSelection = prepareInitialSelection(lastRefreshSelection);
+				}
 				// preserve previous selection
 				if (refreshWithLastSelection && lastRefreshSelection != null && lastRefreshSelection.size() > 0) {
-					list.setSelection(new StructuredSelection(lastRefreshSelection));
+					tableViewer.setSelection(new StructuredSelection(lastRefreshSelection));
 				} else {
 					refreshWithLastSelection = true;
-					list.getTable().setSelection(0);
-					list.getTable().notifyListeners(SWT.Selection, new Event());
+					tableViewer.getTable().setSelection(0);
+					tableViewer.getTable().notifyListeners(SWT.Selection, new Event());
 				}
 			} else {
-				list.setSelection(StructuredSelection.EMPTY);
+				tableViewer.setSelection(StructuredSelection.EMPTY);
 			}
 
 		}
@@ -884,9 +893,32 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 	}
 
 	/**
-	 * Updates the progress label.
+	 * Gets the elements that should be selected when the dialog opens.
+	 * <p>
+	 * Sets the <code>refreshWithLastSelection</code> to true if needed to make sure
+	 * that the initial selection is properly set.
 	 *
-	 * @deprecated
+	 * @param currentSelection the elements selected by default.
+	 *
+	 * @return the initial selection specified by the user or the currentSelection
+	 *         if no initial selection has been set.
+	 */
+	private List<Object> prepareInitialSelection(List<Object> currentSelection) {
+		boolean hasNoInitialSelection = getInitialElementSelections().isEmpty();
+		if (hasNoInitialSelection) {
+			return currentSelection;
+		}
+		refreshWithLastSelection = true;
+		if (!multi) {
+			// if multi selection is disabled then only the first item is selected
+			Object firstSelectedItem = getInitialElementSelections().get(0);
+			return Collections.singletonList(firstSelectedItem);
+		}
+		return getInitialElementSelections();
+	}
+
+	/**
+	 * Updates the progress label.
 	 */
 	@Deprecated
 	public void updateProgressLabel() {
@@ -907,7 +939,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 	 *                        is available
 	 */
 	public void reloadCache(boolean checkDuplicates, IProgressMonitor monitor) {
-		if (list != null && !list.getTable().isDisposed() && contentProvider != null) {
+		if (tableViewer != null && !tableViewer.getTable().isDisposed() && contentProvider != null) {
 			contentProvider.reloadCache(checkDuplicates, monitor);
 		}
 	}
@@ -931,7 +963,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 	@Override
 	protected void computeResult() {
 
-		List<?> selectedElements = list.getStructuredSelection().toList();
+		List<?> selectedElements = tableViewer.getStructuredSelection().toList();
 
 		List<Object> objectsToReturn = new ArrayList<>();
 
@@ -1013,7 +1045,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 	 */
 	protected StructuredSelection getSelectedItems() {
 
-		StructuredSelection selection = (StructuredSelection) list.getStructuredSelection();
+		StructuredSelection selection = (StructuredSelection) tableViewer.getStructuredSelection();
 
 		List<?> selectedItems = selection.toList();
 		Object itemToRemove = null;
@@ -1100,7 +1132,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 	 * @param progressMonitor must be used to report search progress. The state of
 	 *                        this progress monitor reflects the state of the
 	 *                        filtering process.
-	 * @throws CoreException
+	 * @throws CoreException Something went wrong.
 	 */
 	protected abstract void fillContentProvider(AbstractContentProvider contentProvider, ItemsFilter itemsFilter,
 			IProgressMonitor progressMonitor) throws CoreException;
@@ -1111,8 +1143,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 	 * @param items items to be removed
 	 */
 	private void removeSelectedItems(List<?> items) {
-		for (Iterator<?> iter = items.iterator(); iter.hasNext();) {
-			Object item = iter.next();
+		for (Object item : items) {
 			removeHistoryItem(item);
 		}
 		refreshWithLastSelection = false;
@@ -1229,6 +1260,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 	 * items.
 	 * <p>
 	 * Standard invocation scenario:
+	 * </p>
 	 * <ol>
 	 * <li>filtering job (<code>FilterJob</code> class extending <code>Job</code>
 	 * class)</li>
@@ -1236,7 +1268,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 	 * (<code>RefreshCacheJob</code> class extending <code>Job</code> class)</li>
 	 * <li>UI refresh (<code>RefreshJob</code> class extending <code>UIJob</code>
 	 * class)</li>
-	 * <li>cache refresh with checking for duplicates (<cod>CacheRefreshJob</code>
+	 * <li>cache refresh with checking for duplicates (<code>CacheRefreshJob</code>
 	 * class extending <code>Job</code> class)</li>
 	 * <li>UI refresh (<code>RefreshJob</code> class extending <code>UIJob</code>
 	 * class)</li>
@@ -1394,7 +1426,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 
 		@Override
 		public void run() {
-			List<?> selectedElements = ((StructuredSelection) list.getSelection()).toList();
+			List<?> selectedElements = ((StructuredSelection) tableViewer.getSelection()).toList();
 			removeSelectedItems(selectedElements);
 		}
 	}
@@ -1503,7 +1535,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 
 			String str = provider.getText(element);
 			if (selectionDecorator != null && isSelected(element)) {
-				return selectionDecorator.decorateText(str.toString(), element);
+				return selectionDecorator.decorateText(str, element);
 			}
 
 			return str;
@@ -1543,16 +1575,16 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 		}
 
 		private String getSeparatorLabel(String separatorLabel) {
-			Rectangle rect = list.getTable().getBounds();
+			Rectangle rect = tableViewer.getTable().getBounds();
 
-			int borderWidth = list.getTable().computeTrim(0, 0, 0, 0).width;
+			int borderWidth = tableViewer.getTable().computeTrim(0, 0, 0, 0).width;
 
 			int imageWidth = WorkbenchImages.getImage(IWorkbenchGraphicConstants.IMG_OBJ_SEPARATOR).getBounds().width;
 
 			int width = rect.width - borderWidth - imageWidth;
 
-			GC gc = new GC(list.getTable());
-			gc.setFont(list.getTable().getFont());
+			GC gc = new GC(tableViewer.getTable());
+			gc.setFont(tableViewer.getTable().getFont());
 
 			int fSeparatorWidth = gc.getAdvanceWidth('-');
 			int fMessageLength = gc.textExtent(separatorLabel).x;
@@ -1895,7 +1927,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 		 * Filters items.
 		 *
 		 * @param monitor for monitoring progress
-		 * @throws CoreException
+		 * @throws CoreException Something went wrong.
 		 */
 		protected void filterContent(GranualProgressMonitor monitor) throws CoreException {
 
@@ -1944,6 +1976,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 	 * <code>accessed(Object)</code>.
 	 * <p>
 	 * The history can be stored to/loaded from an XML file.
+	 * </p>
 	 */
 	protected static abstract class SelectionHistory {
 
@@ -2101,6 +2134,9 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 	 */
 	protected abstract class ItemsFilter {
 
+		/**
+		 * The {@link SearchPattern}.
+		 */
 		protected SearchPattern patternMatcher;
 
 		/**
@@ -2242,7 +2278,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 		/**
 		 * Matches an item against filter conditions.
 		 *
-		 * @param item
+		 * @param item the item to match
 		 * @return <code>true</code> if item matches against filter conditions,
 		 *         <code>false</code> otherwise
 		 */
@@ -2252,7 +2288,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 		 * Checks consistency of an item. Item is inconsistent if was changed or
 		 * removed.
 		 *
-		 * @param item
+		 * @param item the item to check.
 		 * @return <code>true</code> if item is consistent, <code>false</code> if item
 		 *         is inconsistent
 		 */
@@ -2301,7 +2337,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 		 * Raw result of the searching (unsorted, unfiltered).
 		 * <p>
 		 * Standard object flow:
-		 * <code>items -> lastSortedItems -> lastFilteredItems</code>
+		 * {@code items -> lastSortedItems -> lastFilteredItems}
 		 */
 		private Set<Object> items;
 
@@ -2319,7 +2355,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 		 * Result of the last filtering.
 		 * <p>
 		 * Standard object flow:
-		 * <code>items -> lastSortedItems -> lastFilteredItems</code>
+		 * {@code items -> lastSortedItems -> lastFilteredItems}
 		 */
 		private List<Object> lastFilteredItems;
 
@@ -2327,7 +2363,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 		 * Result of the last sorting.
 		 * <p>
 		 * Standard object flow:
-		 * <code>items -> lastSortedItems -> lastFilteredItems</code>
+		 * {@code items -> lastSortedItems -> lastFilteredItems}
 		 */
 		private List<Object> lastSortedItems;
 
@@ -2387,8 +2423,8 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 		/**
 		 * Adds filtered item.
 		 *
-		 * @param item
-		 * @param itemsFilter
+		 * @param item        the item to add.
+		 * @param itemsFilter the filter to match
 		 */
 		@Override
 		public void add(Object item, ItemsFilter itemsFilter) {
@@ -2406,7 +2442,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 		/**
 		 * Add all history items to <code>contentProvider</code>.
 		 *
-		 * @param itemsFilter
+		 * @param itemsFilter the filter to match
 		 */
 		public void addHistoryItems(ItemsFilter itemsFilter) {
 			if (this.selectionHistory != null) {
@@ -2451,7 +2487,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 			}
 
 			synchronized (lastSortedItems) {
-				Collections.sort(lastSortedItems, getHistoryComparator());
+				lastSortedItems.sort(getHistoryComparator());
 			}
 			return item;
 		}
@@ -2470,13 +2506,13 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 				this.lastSortedItems.remove(item);
 			}
 			synchronized (lastSortedItems) {
-				Collections.sort(lastSortedItems, getHistoryComparator());
+				lastSortedItems.sort(getHistoryComparator());
 			}
 			this.refresh();
 		}
 
 		/**
-		 * @param item
+		 * @param item the item to check
 		 * @return <code>true</code> if given item is part of the history
 		 */
 		public boolean isHistoryElement(Object item) {
@@ -2544,7 +2580,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 				synchronized (lastSortedItems) {
 					lastSortedItems.clear();
 					lastSortedItems.addAll(items);
-					Collections.sort(lastSortedItems, getHistoryComparator());
+					lastSortedItems.sort(getHistoryComparator());
 				}
 			}
 			return lastSortedItems.toArray();
@@ -2553,7 +2589,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 		/**
 		 * Remember result of filtering.
 		 *
-		 * @param itemsFilter
+		 * @param itemsFilter the filter
 		 */
 		public void rememberResult(ItemsFilter itemsFilter) {
 			List<Object> itemsList = Collections.synchronizedList(Arrays.asList(getSortedItems()));
@@ -2585,7 +2621,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 		@Override
 		public void updateElement(int index) {
 
-			FilteredItemsSelectionDialog.this.list
+			FilteredItemsSelectionDialog.this.tableViewer
 					.replace((lastFilteredItems.size() > index) ? lastFilteredItems.get(index) : null, index);
 
 		}
@@ -2613,7 +2649,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 
 			// the TableViewer's root (the input) is treated as parent
 
-			lastFilteredItems = Arrays.asList(getFilteredItems(list.getInput(), subMonitor.split(100)));
+			lastFilteredItems = Arrays.asList(getFilteredItems(tableViewer.getInput(), subMonitor.split(100)));
 
 			if (reset || subMonitor.isCanceled()) {
 				return;
@@ -2630,10 +2666,9 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 						WorkbenchMessages.FilteredItemsSelectionDialog_cacheRefreshJob_checkDuplicates,
 						lastFilteredItems.size());
 				HashMap<String, Object> helperMap = new HashMap<>();
-				for (int i = 0; i < lastFilteredItems.size(); i++) {
+				for (Object item : lastFilteredItems) {
 					if (reset || subMonitor.isCanceled())
 						return;
-					Object item = lastFilteredItems.get(i);
 
 					if (!(item instanceof ItemsListSeparator)) {
 						Object previousItem = helperMap.put(getElementName(item), item);
@@ -2680,9 +2715,8 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 
 			// filter the elements using provided ViewerFilters
 			if (filters != null && filteredElements != null) {
-				for (Iterator<?> iter = filters.iterator(); iter.hasNext();) {
-					ViewerFilter f = (ViewerFilter) iter.next();
-					filteredElements = f.filter(list, parent, filteredElements);
+				for (Object f : filters) {
+					filteredElements = ((ViewerFilter) f).filter(tableViewer, parent, filteredElements);
 					monitor.worked(ticks);
 				}
 			}
