@@ -15,13 +15,13 @@
  *******************************************************************************/
 package org.eclipse.ui.internal.dialogs;
 
+import static org.eclipse.jface.viewers.LabelProvider.createTextImageProvider;
 import static org.eclipse.swt.events.SelectionListener.widgetSelectedAdapter;
 
 import java.nio.charset.Charset;
 import java.nio.charset.IllegalCharsetNameException;
 import java.util.ArrayList;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Objects;
 import java.util.Set;
@@ -265,14 +265,14 @@ public class ContentTypesPreferencePage extends PreferencePage implements IWorkb
 
 		@Override
 		public Object[] getChildren(Object parentElement) {
-			List elements = new ArrayList();
+			List<IContentType> elements = new ArrayList<>();
 			IContentType baseType = (IContentType) parentElement;
 			for (IContentType contentType : manager.getAllContentTypes()) {
 				if (Objects.equals(contentType.getBaseType(), baseType)) {
 					elements.add(contentType);
 				}
 			}
-			return elements.toArray();
+			return elements.toArray(new IContentType[0]);
 		}
 
 		@Override
@@ -357,21 +357,16 @@ public class ContentTypesPreferencePage extends PreferencePage implements IWorkb
 			}
 			return new Object[0];
 		});
-		editorAssociationsViewer.setLabelProvider(new LabelProvider() {
-			@Override
-			public String getText(Object element) {
-				return ((IEditorDescriptor) element).getLabel();
-			}
+		editorAssociationsViewer.setLabelProvider(
+				createTextImageProvider(element -> ((IEditorDescriptor) element).getLabel(),
+						element -> {
+							Image res = ((IEditorDescriptor) element).getImageDescriptor().createImage();
+							if (res != null) {
+								disposableEditorIcons.add(res);
+							}
+							return res;
+						}));
 
-			@Override
-			public Image getImage(Object element) {
-				Image res = ((IEditorDescriptor) element).getImageDescriptor().createImage();
-				if (res != null) {
-					disposableEditorIcons.add(res);
-				}
-				return res;
-			}
-		});
 		Composite buttonsComposite = new Composite(composite, SWT.NONE);
 		buttonsComposite.setLayout(new GridLayout(1, false));
 		buttonsComposite.setLayoutData(new GridData(SWT.FILL, SWT.TOP, false, false));
@@ -481,6 +476,7 @@ public class ContentTypesPreferencePage extends PreferencePage implements IWorkb
 
 	}
 
+	@SuppressWarnings("unchecked")
 	private void createFileAssociations(final Composite parent) {
 		Composite composite = new Composite(parent, SWT.NONE);
 		composite.setLayout(new GridLayout(2, false));
@@ -507,9 +503,7 @@ public class ContentTypesPreferencePage extends PreferencePage implements IWorkb
 				return;
 			}
 			boolean enabled = true;
-			List elements = selection.toList();
-			for (Iterator i = elements.iterator(); i.hasNext();) {
-				Spec spec = (Spec) i.next();
+			for (Spec spec : (Iterable<Spec>) selection) {
 				if (spec.isPredefined) {
 					enabled = false;
 				}
