@@ -16,12 +16,9 @@
 
 package org.eclipse.jface.examples.databinding.snippets;
 
-import java.beans.PropertyChangeListener;
-import java.beans.PropertyChangeSupport;
-
 import org.eclipse.core.databinding.DataBindingContext;
 import org.eclipse.core.databinding.UpdateValueStrategy;
-import org.eclipse.core.databinding.beans.typed.BeanProperties;
+import org.eclipse.core.databinding.beans.typed.PojoProperties;
 import org.eclipse.core.databinding.observable.Realm;
 import org.eclipse.core.databinding.observable.value.IObservableValue;
 import org.eclipse.jface.databinding.swt.DisplayRealm;
@@ -44,57 +41,52 @@ public class Snippet010MasterDetail {
 	public static void main(String[] args) {
 		final Display display = new Display();
 		Realm.runWithDefault(DisplayRealm.getRealm(display), () -> {
-			Shell shell = new Shell(display);
-			shell.setLayout(new GridLayout());
+			Shell shell = createShell();
 
-			Person[] persons = new Person[] { new Person("Me"), new Person("Myself"), new Person("I") };
-
-			ListViewer viewer = new ListViewer(shell);
-			viewer.setContentProvider(new ArrayContentProvider());
-			viewer.setInput(persons);
-
-			Text name = new Text(shell, SWT.BORDER | SWT.READ_ONLY);
-
-			// 1. Observe changes in selection.
-			IObservableValue<Person> selection = ViewerProperties.singleSelection(Person.class).observe(viewer);
-
-			// 2. Observe the name property of the current selection.
-			IObservableValue<String> detailObservable = BeanProperties
-					.value(Person.class, "name", String.class).observeDetail(selection);
-
-			// 3. Bind the Text widget to the name detail (selection's
-			// name).
-			new DataBindingContext().bindValue(WidgetProperties.text(SWT.NONE).observe(name), detailObservable,
-					new UpdateValueStrategy<>(false, UpdateValueStrategy.POLICY_NEVER), null);
-
-			shell.open();
 			while (!shell.isDisposed()) {
-				if (!display.readAndDispatch())
+				if (!display.readAndDispatch()) {
 					display.sleep();
+				}
 			}
 		});
+
 		display.dispose();
 	}
 
+	private static Shell createShell() {
+		Shell shell = new Shell();
+		shell.setLayout(new GridLayout());
+
+		Person[] persons = new Person[] { new Person("Me"), new Person("Myself"), new Person("I") };
+
+		ListViewer viewer = new ListViewer(shell);
+		viewer.setContentProvider(new ArrayContentProvider());
+		viewer.setInput(persons);
+
+		Text name = new Text(shell, SWT.BORDER | SWT.READ_ONLY);
+
+		// 1. Observe changes in selection
+		IObservableValue<Person> selection = ViewerProperties.singleSelection(Person.class).observe(viewer);
+
+		// 2. Observe the name property of the current selection
+		IObservableValue<String> detailObservable = PojoProperties.value(Person.class, "name", String.class)
+				.observeDetail(selection);
+
+		// 3. Bind the Text widget to the name detail (selection's name)
+		new DataBindingContext().bindValue(WidgetProperties.text(SWT.NONE).observe(name), detailObservable,
+				UpdateValueStrategy.never(), null);
+
+		shell.open();
+		return shell;
+	}
+
 	public static class Person {
 		private String name;
-		private PropertyChangeSupport changeSupport = new PropertyChangeSupport(this);
 
 		Person(String name) {
 			this.name = name;
 		}
 
-		public void addPropertyChangeListener(PropertyChangeListener listener) {
-			changeSupport.addPropertyChangeListener(listener);
-		}
-
-		public void removePropertyChangeListener(PropertyChangeListener listener) {
-			changeSupport.removePropertyChangeListener(listener);
-		}
-
-		/**
-		 * @return Returns the name.
-		 */
 		public String getName() {
 			return name;
 		}
