@@ -10,6 +10,8 @@
  *******************************************************************************/
 package org.eclipse.urischeme.internal.registration;
 
+import java.util.Objects;
+
 import org.eclipse.urischeme.IScheme;
 
 /**
@@ -37,4 +39,18 @@ public class Scheme implements IScheme {
 		return desription;
 	}
 
+	@Override
+	public boolean equals(Object o) {
+		if (o.getClass() != this.getClass()) {
+			return false;
+		}
+		Scheme other = (Scheme) o;
+		return Objects.equals(this.name, other.name) && Objects.equals(this.desription, other.desription);
+	}
+
+	@Override
+	public int hashCode() {
+		return Objects.hash(name, desription);
+	}
+
 }
