@@ -211,7 +211,7 @@ public class DialogCheck {
 		if (preferred.x > size.x) {
 			//close the dialog
 			button.getShell().dispose();
-			assertTrue(message.toString(), false);
+			assertTrue(message, false);
 		}
 	}
 
@@ -225,7 +225,7 @@ public class DialogCheck {
 		String widget = label.toString();
 		Point size = label.getSize();
 		String labelText = label.getText();
-		if (labelText == null || labelText.length() == 0)
+		if (labelText == null || labelText.isEmpty())
 			return;
 		//compute the size with no line wrapping
 		Point preferred = label.computeSize(SWT.DEFAULT, SWT.DEFAULT);
@@ -243,7 +243,7 @@ public class DialogCheck {
 		if (preferred.x > size.x) {
 			//close the dialog
 			label.getShell().dispose();
-			assertTrue(message.toString(), false);
+			assertTrue(message, false);
 		}
 	}
 
