@@ -18,27 +18,29 @@ import java.net.URL;
 
 import org.eclipse.core.runtime.FileLocator;
 import org.eclipse.jface.resource.ImageDescriptor;
+import org.eclipse.jface.resource.ResourceLocator;
 import org.eclipse.swt.graphics.Image;
-import org.eclipse.ui.plugin.AbstractUIPlugin;
 import org.eclipse.ui.tests.harness.util.ImageTests;
 import org.eclipse.ui.tests.harness.util.UITestCase;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
 
 /**
- * Tests to ensure that various icon scenarios work.  These are tested on
- * editors but should be applicable for any client of
- * AbstractUIPlugin.imageDescriptorFromPlugin()
+ * Tests to ensure that various icon scenarios work. These are tested on editors
+ * but should be applicable for any client of
+ * {@link ResourceLocator#imageDescriptorFromBundle(String, String)}
  *
  * @since 3.0
  */
+@RunWith(JUnit4.class)
 public class EditorIconTest extends UITestCase {
 
-	/**
-	 * @param testName
-	 */
-	public EditorIconTest(String testName) {
-		super(testName);
+	public EditorIconTest() {
+		super(EditorIconTest.class.getSimpleName());
 	}
 
+	@Test
 	public void testDependantBundleIcon() {
 		Image i1 = null;
 		Image i2 = null;
@@ -46,8 +48,8 @@ public class EditorIconTest extends UITestCase {
 		try {
 			i1 = fWorkbench.getEditorRegistry().getDefaultEditor(
 					"foo.icontest1").getImageDescriptor().createImage();
-			i2 = AbstractUIPlugin.imageDescriptorFromPlugin("org.eclipse.ui",
-					"icons/full/obj16/font.png").createImage();
+			i2 = ResourceLocator.imageDescriptorFromBundle("org.eclipse.ui", "icons/full/obj16/font.png")
+					.orElseThrow(() -> new AssertionError()).createImage();
 			ImageTests.assertEquals(i1, i2);
 		}
 		finally {
@@ -60,15 +62,16 @@ public class EditorIconTest extends UITestCase {
 		}
 	}
 
+	@Test
 	public void testNonDependantBundleIcon() {
 		Image i1 = null;
 		Image i2 = null;
 		try {
 			i1 = fWorkbench.getEditorRegistry().getDefaultEditor(
 					"foo.icontest2").getImageDescriptor().createImage();
-			i2 = AbstractUIPlugin.imageDescriptorFromPlugin(
+			i2 = ResourceLocator.imageDescriptorFromBundle(
 					"org.eclipse.jdt.ui", "icons/full/obj16/class_obj.png") // layer breaker!
-					.createImage();
+					.orElseThrow(() -> new AssertionError()).createImage();
 			ImageTests.assertEquals(i1, i2);
 		}
 		finally {
@@ -81,6 +84,7 @@ public class EditorIconTest extends UITestCase {
 		}
 	}
 
+	@Test
 	public void testBadIcon() {
 		Image i1 = null;
 		Image i2 = null;
@@ -88,8 +92,8 @@ public class EditorIconTest extends UITestCase {
 		try {
 			i1 = fWorkbench.getEditorRegistry().getDefaultEditor(
 					"foo.icontest3").getImageDescriptor().createImage();
-			i2 = AbstractUIPlugin.imageDescriptorFromPlugin("org.eclipse.ui",
-					"icons/full/obj16/file_obj.png").createImage();
+			i2 = ResourceLocator.imageDescriptorFromBundle("org.eclipse.ui", "icons/full/obj16/file_obj.png")
+					.orElseThrow(() -> new AssertionError()).createImage();
 			ImageTests.assertEquals(i1, i2);
 		}
 		finally {
@@ -105,9 +109,11 @@ public class EditorIconTest extends UITestCase {
 	/**
 	 * Tests undocumented support for platform:/plugin/... URLs.
 	 */
+	@Test
 	public void testBug395126() {
-		ImageDescriptor imageDescriptor = AbstractUIPlugin.imageDescriptorFromPlugin("org.eclipse.jface",
-				"platform:/plugin/org.eclipse.jface/$nl$/icons/full/message_error.png");
+		ImageDescriptor imageDescriptor = ResourceLocator.imageDescriptorFromBundle("org.eclipse.jface",
+				"platform:/plugin/org.eclipse.jface/$nl$/icons/full/message_error.png")
+				.orElseThrow(() -> new AssertionError());
 		Image image = null;
 		try {
 			image = imageDescriptor.createImage(false);
@@ -122,9 +128,10 @@ public class EditorIconTest extends UITestCase {
 	/**
 	 * Tests undocumented support for platform:/plugin/... URLs.
 	 */
+	@Test
 	public void testBug395126_missing() {
-		ImageDescriptor imageDescriptor = AbstractUIPlugin.imageDescriptorFromPlugin("org.eclipse.jface",
-				"platform:/plugin/org.eclipse.jface/$nl$/icons/does-not-exist.gif");
+		ImageDescriptor imageDescriptor = ResourceLocator.imageDescriptorFromBundle("org.eclipse.jface",
+				"platform:/plugin/org.eclipse.jface/$nl$/icons/does-not-exist.gif").orElse(null);
 		Image image = null;
 		try {
 			image = imageDescriptor.createImage(false);
@@ -139,10 +146,11 @@ public class EditorIconTest extends UITestCase {
 	/**
 	 * Tests undocumented support for arbitrary URLs.
 	 */
+	@Test
 	public void testBug474072() throws Exception {
 		URL url = FileLocator.find(new URL("platform:/plugin/org.eclipse.jface/$nl$/icons/full/message_error.png"));
-		ImageDescriptor imageDescriptor = AbstractUIPlugin.imageDescriptorFromPlugin("org.eclipse.jface",
-				url.toString());
+		ImageDescriptor imageDescriptor = ResourceLocator.imageDescriptorFromBundle("org.eclipse.jface", url.toString())
+				.orElseThrow(() -> new AssertionError());
 		Image image = null;
 		try {
 			image = imageDescriptor.createImage(false);
@@ -157,11 +165,13 @@ public class EditorIconTest extends UITestCase {
 	/**
 	 * Tests undocumented support for arbitrary URLs.
 	 */
+	@Test
 	public void testBug474072_missing() throws Exception {
 		String url = FileLocator.find(new URL("platform:/plugin/org.eclipse.jface/$nl$/icons/full/message_error.png"))
 				.toString();
 		url += "does-not-exist";
-		ImageDescriptor imageDescriptor = AbstractUIPlugin.imageDescriptorFromPlugin("org.eclipse.jface", url);
+		ImageDescriptor imageDescriptor = ResourceLocator.imageDescriptorFromBundle("org.eclipse.jface", url)
+				.orElse(null);
 		Image image = null;
 		try {
 			image = imageDescriptor.createImage(false);
